<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
'0_langue' => 'Asturianu [ast]',
'0_liste' => 'spip-es@rezo.net',
'0_mainteneur' => 'spip-dev@rezo.net',

// A
'access_interface_graphique' => 'Tornar a la interfaz gr&aacute;fica completa',
'access_mode_texte' => 'Amosar l\'interfaz simple en mou testu',
'admin_debug' => 'debug',
'admin_modifier_article' => 'Iguar esti art&iacute;culu',
'admin_modifier_auteur' => 'Camudar esti autor',
'admin_modifier_breve' => 'Camudar esta breve',
'admin_modifier_mot' => 'Camudar esta pallabra-clave',
'admin_modifier_rubrique' => 'Iguar la estaya',
'admin_recalculer' => 'Recalcular esta p&aacute;xina',
'afficher_trad' => 'amosar les tornes',
'alerte_maj_impossible' => '<b>&iexcl;Alerta!</b> El remocique de la base SQL a la versi&oacute;n @version@ nun ye posible, seique por un problema de permisos pa camudar la base de datos. Contauta col to agospiamientu web.',
'alerte_modif_info_concourante' => 'ATENCI&Oacute;N: Esta informaci&oacute;n camudose n\'otru llugar. El valor actual ye:',
'analyse_xml' => 'An&aacute;lisis XML',
'annuler' => 'Anular',
'antispam_champ_vide' => 'Esti campu tien que quedar vac&iacute;u:',
'articles_recents' => 'Art&iacute;culos m&aacute;s nuevos',
'avis_archive_incorrect' => 'El ficheru d\'archivu nun ye un ficheru de SPIP',
'avis_archive_invalide' => 'el ficheru d\'archivu nun ye v&aacute;lidu',
'avis_attention' => '&iexcl;CUIDAU!',
'avis_champ_incorrect_type_objet' => 'Nome de campu incorr&eacute;utu @name@ pal oxetu de tipu @type@',
'avis_colonne_inexistante' => 'La columna @col@ nun esiste',
'avis_echec_syndication_01' => 'Fallu na sindicaci&oacute;n: el backend indic&aacute;u ye indescifrable o nun tien deng&uacute;n art&iacute;culu.',
'avis_echec_syndication_02' => 'Fallu na sindicaci&oacute;n: ye imposible allegase al backend d\'esti sitiu.',
'avis_erreur' => 'Error: ver embaxo.',
'avis_erreur_connexion' => 'Fallu de conex&oacute;n',
'avis_erreur_cookie' => 'problema de cookie',
'avis_erreur_fonction_contexte' => 'Fallu de programaci&oacute;n. Esta funci&oacute;n nun tien que llamase n\'esi contestu.',
'avis_erreur_mysql' => 'Fallu de SQL',
'avis_erreur_sauvegarde' => '&iexcl;Fallu na copia de segurid&aacute; (@type@ @id_objet@)!',
'avis_erreur_visiteur' => 'Problema cola entrada al espaciu priv&aacute;u',

// B
'barre_a_accent_grave' => 'Amestar una A may&uacute;scula con acentu grave',
'barre_aide' => 'Usa los atayos tipogr&aacute;ficos para iguar meyor la presentaci&oacute;n del testu',
'barre_e_accent_aigu' => 'Amestar una E may&uacute;scula con tilde',
'barre_eo' => 'Amestar una E a la O',
'barre_eo_maj' => 'Amestar una E cola O may&uacute;scula',
'barre_euro' => 'Amestar la marca &euro;',
'barre_gras' => 'Poner en {{negrina}}',
'barre_guillemets' => 'Poner ente &laquo;comines&raquo;',
'barre_guillemets_simples' => 'Poner ente &#147;comines de segundu nivel&#148;',
'barre_intertitre' => 'Camudar a {{{inter-t&iacute;tulu}}}',
'barre_italic' => 'Poner en {cursiva}',
'barre_lien' => 'Camudar a [enllaz d\'hipertestu->http://...]',
'barre_lien_input' => 'Indica les se&ntilde;es del to enllaz. Pueden conse&ntilde;ase unes se&ntilde;es web na forma http://www.talsitiu.ast/direutoriu/ o s&oacute;lo poner el n&uacute;mberu d\'un art&iacute;culu d\'esti sitiu.',
'barre_note' => 'Camudar en [[Nota de pie de p&aacute;xina]]',
'barre_paragraphe' => 'Crear un p&aacute;rrafu',
'barre_quote' => '<quote>Citar un mensaxe</quote>',
'bouton_ajouter_document' => 'Amestar un documentu',
'bouton_ajouter_image' => 'Amestar una imaxe',
'bouton_ajouter_image_document' => 'Amestar una imaxe o&nbsp;un&nbsp;documentu',
'bouton_changer' => 'Camudar',
'bouton_chercher' => 'Restolar',
'bouton_choisir' => 'Escoyer',
'bouton_download' => 'Descargar',
'bouton_enregistrer' => 'Guardar',
'bouton_radio_desactiver_messagerie_interne' => 'Desactivar los mensaxes internos',
'bouton_radio_envoi_annonces' => 'Unviar anuncies editoriales',
'bouton_radio_non_envoi_annonces' => 'Nun unviar anuncies',
'bouton_radio_non_envoi_liste_nouveautes' => 'Nun unviar la llista de noved&aacute;es',
'bouton_recharger_page' => 'recargar esta p&aacute;xina',
'bouton_telecharger' => 'Subir',
'bouton_valider' => 'Validar',

// C
'cal_apresmidi' => 'tardi',
'cal_jour_entier' => 'd&iacute;a enteru',
'cal_matin' => 'ma&ntilde;ana',
'cal_par_jour' => 'calendariu por d&iacute;a',
'cal_par_mois' => 'calendariu por mes',
'cal_par_semaine' => 'calendariu por selmana',
'choix_couleur_interface' => 'color ',
'choix_interface' => 'escoyeta de l\'interfaz',
'colonne' => 'Columna',
'confirm_changer_statut' => 'Atenci&oacute;n, acabes de pidir el camb&eacute;u de l\'est&aacute;u d\'esti elementu. &iquest;Qui&eacute;s continuar?',
'correcte' => 'correuta',

// D
'date_aujourdhui' => 'g&uuml;ei',
'date_avant_jc' => 'aC',
'date_dans' => 'en @delai@',
'date_de_mois_1' => '@j@ de @nommois@',
'date_de_mois_10' => '@j@ d\'@nommois@',
'date_de_mois_11' => '@j@ de @nommois@',
'date_de_mois_12' => '@j@ d\'@nommois@',
'date_de_mois_2' => '@j@ de @nommois@',
'date_de_mois_3' => '@j@ de @nommois@',
'date_de_mois_4' => '@j@ d\'@nommois@',
'date_de_mois_5' => '@j@ de @nommois@',
'date_de_mois_6' => '@j@ de @nommois@',
'date_de_mois_7' => '@j@ de @nommois@',
'date_de_mois_8' => '@j@ d\'@nommois@',
'date_de_mois_9' => '@j@ de @nommois@',
'date_demain' => 'ma&ntilde;ana',
'date_fmt_heures_minutes' => '@h@h.@m@min.',
'date_fmt_jour_heure' => '@jour@ a les @heure@',
'date_fmt_jour_mois' => '@jour@ de @nommois@',
'date_fmt_jour_mois_annee' => '@jour@ de @nommois@ de @annee@',
'date_fmt_mois_annee' => '@nommois@ de @annee@',
'date_fmt_nomjour_date' => 'el @nomjour@ @date@',
'date_heures' => 'hores',
'date_hier' => 'ayeri',
'date_il_y_a' => 'hai @delai@',
'date_jnum1' => '1u',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'domingu',
'date_jour_1_abbr' => 'dom.',
'date_jour_1_initiale' => 'd.',
'date_jour_2' => 'llunes',
'date_jour_2_abbr' => 'llu.',
'date_jour_2_initiale' => 'l.',
'date_jour_3' => 'martes',
'date_jour_3_abbr' => 'mar.',
'date_jour_3_initiale' => 'm.',
'date_jour_4' => 'mi&eacute;rcoles',
'date_jour_4_abbr' => 'mi&eacute;.',
'date_jour_4_initiale' => 'm.',
'date_jour_5' => 'xueves',
'date_jour_5_abbr' => 'xue.',
'date_jour_5_initiale' => 'x.',
'date_jour_6' => 'vienres',
'date_jour_6_abbr' => 'vie.',
'date_jour_6_initiale' => 'v.',
'date_jour_7' => 's&aacute;badu',
'date_jour_7_abbr' => 's&aacute;b.',
'date_jour_7_initiale' => 's.',
'date_jours' => 'd&iacute;es',
'date_minutes' => 'minutos',
'date_mois' => 'meses',
'date_mois_1' => 'xineru',
'date_mois_10' => 'ochobre',
'date_mois_11' => 'payares',
'date_mois_12' => 'avientu',
'date_mois_2' => 'febreru',
'date_mois_3' => 'marzu',
'date_mois_4' => 'abril',
'date_mois_5' => 'mayu',
'date_mois_6' => 'xunu',
'date_mois_7' => 'xunetu',
'date_mois_8' => 'agostu',
'date_mois_9' => 'setiembre',
'date_saison_1' => 'iviernu',
'date_saison_2' => 'primavera',
'date_saison_3' => 'branu',
'date_saison_4' => 'seronda',
'date_secondes' => 'segundos',
'date_semaines' => 'selmanes',
'date_un_mois' => 'mes',
'date_une_heure' => 'hora',
'date_une_minute' => 'minutu',
'date_une_seconde' => 'segundu',
'date_une_semaine' => 'selmana',
'dirs_commencer' => 'pa entamar dafechu la instalaci&oacute;n',
'dirs_preliminaire' => 'Previo: <b>Iguar los permisos d\'accesu</b>',
'dirs_probleme_droits' => 'Problema colos permisos d\'accesu',
'dirs_repertoires_absents' => '<p><b>Nun s\'atoparon los direutorios siguientes:</b></p><ul>@bad_dirs@</ul>
  <p>Ye probable qu\'el problema seya por cuenta d\'una equivocaci&oacute;n coles may&uacute;scules o min&uacute;scules.
  Comprueba que les min&uacute;scules y may&uacute;scules d\'estos direutorios concasen bien coles que s\'amuesen
  enriba; si nun ye\'l casu, renoma los direutorios col to programa de FTP pa iguar el fallu.</p>
  <p>De magar fechu esti camb&eacute;u, vas poder ',
'dirs_repertoires_suivants' => '<p><b>Los direutorios siguientes nun son accesibles pa escritura:</b></p> <ul>@bad_dirs@</ul>
  <p>Pa igualo, usa el to cliente FTP pa reglar los permisos d\'accesu de ca&uacute;n
  d\'estos direutorios. El procesu espl&iacute;case en detalle na gu&iacute;a d\'asitiamientu.</p>
  <p>De magar fechu el camb&eacute;u, vas poder ',
'double_occurrence' => 'Ocurrencia doble de @balise@',

// E
'en_cours' => 'en cursu',
'entree_dimensions' => 'Dimensiones:',
'entree_titre_document' => 'T&iacute;tulu del documentu:',
'entree_titre_image' => 'T&iacute;tulu de la imaxe:',
'envoi_via_le_site' => 'Unviu mand&aacute;ndose del sitiu',
'erreur' => 'Error',
'erreur_balise_non_fermee' => 'cabera baliza nun pesllada:',
'erreur_texte' => 'fallu(os)',
'etape' => 'Etapa',

// F
'fichier_introuvable' => 'Nun s\'alcuentra el ficheru @fichier@',
'form_auteur_confirmation' => 'Confirmez votre adresse email', # NEW
'form_auteur_email_modifie' => 'Votre adresse email a &eacute;t&eacute; modifi&eacute;e.', # NEW
'form_auteur_envoi_mail_confirmation' => 'Un courrier &eacute;lectronique de confirmation vient d\'&ecirc;tre envoy&eacute; &agrave; @email@. Vous devrez visiter l\'adresse Web mentionn&eacute;e dans ce courrier pour valider votre adresse mail.', # NEW
'form_auteur_mail_confirmation' => 'Bonjour,

Vous avez demand&eacute; &agrave; changer votre adresse email.
Pour confirmer votre nouvelle adresse, il suffit de vous connecter &agrave;
l\'adresse ci-dessous (dans le cas contraire, votre demande
sera ignor&eacute;e) :

    @url@
', # NEW
'form_deja_inscrit' => 'Ya tas apunt&aacute;u.',
'form_email_non_valide' => 'Les se&ntilde;es de corr&eacute;u electr&oacute;nicu nun son v&aacute;lides.',
'form_forum_access_refuse' => 'Ya nun ties accesu a esti sitiu.',
'form_forum_bonjour' => 'Hola, @nom@,',
'form_forum_email_deja_enregistre' => 'Estes se&ntilde;es de corr&eacute;u electr&oacute;nicu ya tan rexistr&aacute;es; poro, puedes usar la to contrase&ntilde;a normal.',
'form_forum_identifiant_mail' => 'La to nueva identificaci&oacute;n ta acabante d\'unviase por email.',
'form_forum_identifiants' => 'Identificaci&oacute;n personal',
'form_forum_indiquer_nom_email' => 'Indica equ&iacute; el to nome y les tos se&ntilde;es d\'email. La to identificaci&oacute;n personal va llegate de secute por corr&eacute;u ellectr&oacute;nicu.',
'form_forum_login' => 'login:',
'form_forum_message_auto' => '(esti ye un mensaxe autom&aacute;ticu)',
'form_forum_pass' => 'contrase&ntilde;a:',
'form_forum_probleme_mail' => 'Problema col corr&eacute;u: nun pudo mandase la identificaci&oacute;n.',
'form_forum_voici1' => 'Esta ye la to identificaci&oacute;n pa que puedas participar dafechu
nel sitiu "@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => 'Esta ye la to identificaci&oacute;n pa proponer art&iacute;culos nel
sitiu "@nom_site_spip@" (@adresse_login@):',
'form_indiquer_email' => 'Pon les tos se&ntilde;es de corr&eacute;u electr&oacute;nicu.',
'form_indiquer_nom' => 'Indica el to nome.',
'form_indiquer_nom_site' => 'Indica el nome del to sitiu Web.',
'form_pet_adresse_site' => 'Se&ntilde;es del to sitiu',
'form_pet_aucune_signature' => 'Denguna robla concasa con esi c&oacute;digu...',
'form_pet_confirmation' => 'Confirma equ&iacute; la to firma:',
'form_pet_deja_enregistre' => 'Esti sitiu ya ta rexistr&aacute;u',
'form_pet_deja_signe' => 'Ya roblaste esti testu.',
'form_pet_envoi_mail_confirmation' => 'Acaba de mandase un corr&eacute;u electr&oacute;nicu de confirmaci&oacute;n a @email@. Vas tener que visitar la direici&oacute;n Web que se menta nesi corr&eacute;u pa validar la to firma.',
'form_pet_mail_confirmation' => 'Bones,

Vienes de pidir la firma de la solicit&uacute;:
@titre@.

Pa ello diste la siguiente informaci&oacute;n:
    Nome: @nom_email@
    Sitiu Web: @nom_site@ - @url_site@
    @message@

IMPORTANTE...
Pa validar la to firma, val con conectate a la
direici&oacute;n d\'embaxo (en casu contrariu, va refugase
la to solicit&uacute;):

    @url@


Gracies por participar
',
'form_pet_message_commentaire' => '&iquest;Un mensaxe, un comentariu?',
'form_pet_nom_site2' => 'Nome del to sitiu Web',
'form_pet_probleme_liens' => 'Ties que iguar el to mensaxe quitando-y los enllaces d\'hipertestu.',
'form_pet_probleme_technique' => 'Hai un problema t&eacute;unicu, les firmes tan temporalmente suspend&iacute;es.',
'form_pet_signature_pasprise' => 'La to firma nun se tuvo en cuenta.',
'form_pet_signature_validee' => 'La to firma ta validada. &iexcl;Gracies!',
'form_pet_site_deja_enregistre' => 'Esti sitiu ya ta rexistr&aacute;u',
'form_pet_url_invalide' => 'L\'URL que indicaste nun ye v&aacute;lida.',
'form_pet_votre_email' => 'Les tos se&ntilde;es de corr&eacute;u electr&oacute;nicu',
'form_pet_votre_nom' => 'El to nome o nomatu',
'form_pet_votre_site' => 'Si tienes un sitiu Web, puedes conse&ntilde;alu darr&eacute;u',
'form_prop_confirmer_envoi' => 'Confirmar l\'unv&iacute;u',
'form_prop_description' => 'Descripci&oacute;n/comentariu',
'form_prop_enregistre' => 'La to propuesta qued&oacute; rexistrada, apaecer&aacute; en ll&iacute;nia tres de la validaci&oacute;n polos responsables d\'esti sitiu.',
'form_prop_envoyer' => 'Unviar un mensaxe',
'form_prop_indiquer_email' => 'Hai qu\'indicar unes se&ntilde;es d\'email v&aacute;lides',
'form_prop_indiquer_nom_site' => 'Hai qu\'indicar el nome del sitiu.',
'form_prop_indiquer_sujet' => 'Hai qu\'indicar un asuntu',
'form_prop_message_envoye' => 'Mensaxe unvi&aacute;u',
'form_prop_nom_site' => 'Nome del sitiu',
'form_prop_non_enregistre' => 'La to propuesta nun qued&oacute; rexistrada.',
'form_prop_sujet' => 'Asuntu',
'form_prop_url_site' => 'Se&ntilde;es (URL) del sitiu',
'forum_acces_refuse' => 'Ya nun ties accesu a estos foros.',
'forum_attention_dix_caracteres' => '<b>&iexcl;Atenci&oacute;n!</b> el mensaxe tien que tener polo menos diez carauteres.',
'forum_attention_trois_caracteres' => '<b>&iexcl;Atenci&oacute;n!</b> el t&iacute;tulu tien que tener polo menos tres carauteres.',
'forum_attention_trop_caracteres' => '<b>&iexcl;Atenci&oacute;n!</b> esti mensaxe ye enforma llargu (@compte@ carauteres): pa que pueda rexistrase, nun tien que pasar de @max@ carauteres.',
'forum_avez_selectionne' => 'Seleicionasti:',
'forum_cliquer_retour' => 'Calca <a href=\'@retour_forum@\'>equ&iacute;</a> pa continuar.',
'forum_forum' => 'foru',
'forum_info_modere' => 'Esti foru ta llend&aacute;u de mano: la to aportaci&oacute;n nun va apaecer fasta qu\'un alministrador del sitiu nun-y de el preste.',
'forum_lien_hyper' => '<b>Enllace d\'hipertestu</b> (opcional)',
'forum_message_definitif' => 'Mensaxe definitivu: unviar al sitiu',
'forum_message_trop_long' => 'El to mensaxe ye enforma llargu. El tama&ntilde;u m&aacute;simu ye de 20000 carauteres.',
'forum_ne_repondez_pas' => 'Nun responder a esti corr&eacute;u, sinon nel foru de les siguientes se&ntilde;es:',
'forum_non_inscrit' => 'Nun tas apunt&aacute;u, o les tos se&ntilde;es o contrase&ntilde;a tan equivoc&aacute;os.',
'forum_page_url' => '(Si el to mensaxe refierse a un art&iacute;culu espubliz&aacute;u na Rede, o a una p&aacute;xina que tenga m&aacute;s informaci&oacute;n, equ&iacute; embaxo vas poder indicar el t&iacute;tulu de la p&aacute;xina y les sos se&ntilde;es.)',
'forum_par_auteur' => 'por @auteur@',
'forum_poste_par' => 'Mensaxe unvi&aacute;u @parauteur@ tocante a l\'art&iacute;culu &laquo;@titre@&raquo;.',
'forum_probleme_database' => 'Problema de base datos, el to mensaxe nun qued&oacute; rexistr&aacute;u.',
'forum_qui_etes_vous' => '<b>&iquest;Qui&eacute;n yes?</b> (opcional)',
'forum_texte' => 'Testu del to mensaxe:',
'forum_titre' => 'T&iacute;tulu:',
'forum_titre_erreur' => 'Error...',
'forum_url' => 'URL:',
'forum_valider' => 'Validar la escoyeta',
'forum_voir_avant' => 'Ver el mensaxe enantes de publicalu',
'forum_votre_email' => 'Les tos se&ntilde;es d\'email:',
'forum_votre_nom' => 'El to nome (o nomatu):',
'forum_vous_enregistrer' => 'Pa poder participar nesti
  foru, primero hai que rexistrase.
  Escribe embaxo l\'identificador personal que
  recibisti. Si nun tas rexistr&aacute;u, ties que',
'forum_vous_inscrire' => 'inscribite.',

// I
'ical_texte_rss_articles' => 'El ficheru &laquo;backend&raquo; de los art&iacute;culos d\'esti sitiu alcu&eacute;ntrase na direici&oacute;n:',
'ical_texte_rss_articles2' => 'Lo mesmo puedes alcontrar ficheros &laquo;backend&raquo; pa los art&iacute;culos de cada estaya d\'esti sitiu:',
'ical_texte_rss_breves' => 'Am&aacute;s esiste un ficheru que conti&eacute;n les breves del sitiu. Escribiendo un n&uacute;mberu d\'estaya, tendr&aacute;s nam&aacute;i les breves d\'esa estaya.',
'icone_a_suivre' => 'A siguir',
'icone_admin_site' => 'Alministraci&oacute;n del sitiu',
'icone_agenda' => 'Axenda',
'icone_aide_ligne' => 'Aida',
'icone_articles' => 'Art&iacute;culos',
'icone_auteurs' => 'Autores',
'icone_breves' => 'Breves',
'icone_brouteur' => '&Ntilde;avegaci&oacute;n r&aacute;pida',
'icone_configuration_site' => 'Configuraci&oacute;n',
'icone_configurer_site' => 'Configurar esti sitiu',
'icone_creer_nouvel_auteur' => 'Crear un autor nuevu',
'icone_creer_rubrique' => 'Crear una estaya',
'icone_creer_sous_rubrique' => 'Crear una so-estaya',
'icone_deconnecter' => 'Desconeutase',
'icone_discussions' => 'Discutinios',
'icone_doc_rubrique' => 'Documentos de les estayes',
'icone_ecrire_article' => 'Escribir un art&iacute;culu nuevu',
'icone_edition_site' => 'Edici&oacute;n',
'icone_forum_administrateur' => 'Foru d\'alministradores',
'icone_forum_suivi' => 'Siguimientu de los foros',
'icone_gestion_langues' => 'Xesti&oacute;n de les lling&uuml;es',
'icone_informations_personnelles' => 'Informaci&oacute;n personal',
'icone_interface_complet' => 'interfaz completa',
'icone_interface_simple' => 'Interfaz simplificada',
'icone_maintenance_site' => 'Mantenimientu del sitiu',
'icone_messagerie_personnelle' => 'Mensaxer&iacute;a personal',
'icone_mots_cles' => 'Pallabres-clave',
'icone_nouvelle_breve' => 'Escribir una breve nueva',
'icone_repartition_actuelle' => 'Amosar el repartu actual',
'icone_repartition_debut' => 'Amosar el repartu dende l\'entamu',
'icone_repartition_visites' => 'Repartu de les visites',
'icone_rubriques' => 'Estayes',
'icone_sauver_site' => 'Copia de segurid&aacute; del sitiu',
'icone_site_entier' => 'El sitiu enteru',
'icone_sites_references' => 'Sitios referenciaos',
'icone_statistiques' => 'Estad&iacute;stiques del sitiu',
'icone_statistiques_visites' => 'Estad&iacute;stiques',
'icone_suivi_activite' => 'Siguir l\'activid&aacute; del sitiu',
'icone_suivi_actualite' => 'Evoluci&oacute;n del&nbsp;sitiu',
'icone_suivi_forums' => 'Siguir/xestionar los foros',
'icone_suivi_pettions' => 'Siguir/xestionar les solicitudes',
'icone_suivi_revisions' => 'Camb&eacute;os de los art&iacute;culos',
'icone_supprimer_document' => 'Desaniciar esti documentu',
'icone_supprimer_image' => 'Desaniciar esta imaxen',
'icone_supprimer_message' => 'Desaniciar esti mensaxe',
'icone_tous_articles' => 'Tolos art&iacute;culos de to',
'icone_tous_auteur' => 'Tolos autores',
'icone_valider_message' => 'Validar esti mensaxe',
'icone_visiter_site' => 'Visitar',
'icone_voir_en_ligne' => 'Ver en llinia',
'image_tourner_180' => 'Voltiar 180&deg;',
'image_tourner_droite' => 'Voltiar 90&deg; a la derecha',
'image_tourner_gauche' => 'Voltiar 90&deg; a la izquierda',
'img_indisponible' => 'imaxe non disponible',
'impossible' => 'imposible',
'info_a_suivre' => 'A SIGUIR&raquo;',
'info_a_valider' => '[a validar]',
'info_acces_interdit' => 'Accesu torg&aacute;u',
'info_acces_refuse' => 'Accesu refug&aacute;u',
'info_action' => 'Aici&oacute;n: @action@',
'info_administrer_rubriques' => 'Puedes alministrar esta estaya y les dependientes d\'ella',
'info_adresse_non_indiquee' => '&iexcl;Nun indicasti qu&eacute; se&ntilde;es hai que prebar!',
'info_aide' => 'AIDA:',
'info_ajouter_mot' => 'Amestar esta pallabra',
'info_annonce' => 'ANUNCIU',
'info_annonces_generales' => 'Anuncios xenerales:',
'info_article_propose' => 'Art&iacute;culu propuestu',
'info_article_publie' => 'Art&iacute;culu espubliz&aacute;u',
'info_article_redaction' => 'Art&iacute;culu en cursu de redaici&oacute;n',
'info_article_refuse' => 'Art&iacute;culu refug&aacute;u',
'info_article_supprime' => 'Art&iacute;culu desanici&aacute;u',
'info_articles' => 'Art&iacute;culos',
'info_articles_a_valider' => 'Los art&iacute;culos por validar',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Art&iacute;culos propuestos',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'autor(es):',
'info_authentification_ftp' => 'Autentificaci&oacute;n (per FTP).',
'info_bloquer_lien' => 'bloquiar esti enllace',
'info_breves_02' => 'Breves',
'info_breves_2' => 'breves',
'info_breves_nb' => '@nb@ br&egrave;ves', # NEW
'info_breves_un' => '1 br&egrave;ve', # NEW
'info_breves_valider' => 'Curties por validar',
'info_connexion_refusee' => 'Conex&oacute;n refugada',
'info_contact_developpeur' => 'Ponte en contautu con un desendolcador.',
'info_contenance' => 'Esti sitiu contien:',
'info_contribution' => 'contribuciones del foru',
'info_copyright' => '@spip@ ye un programa llibre distribuy&iacute;u @lien_gpl@.',
'info_copyright_doc' => 'Pa m&aacute;s informaci&oacute;n, dir al sitiu <a href="@spipnet@">http://www.spip.net/</a>.',
'info_copyright_gpl' => 'so llicencia GPL',
'info_cours_edition' => 'Los tos art&iacute;culos en cursu de redaici&oacute;n',
'info_creer_repertoire' => 'Debes crear un ficheru o un direutoriu nom&aacute;u:',
'info_creer_repertoire_2' => 'dientro\'l direutoriu <b>@repertoire@</b>, y llueu:',
'info_creer_vignette' => 'creaci&oacute;n autom&aacute;tica de la vi&ntilde;eta',
'info_deplier' => 'Desplegar',
'info_descriptif_nombre' => 'descripci&oacute;n(es):',
'info_description' => 'Descripci&oacute;n:',
'info_description_2' => 'Descripci&oacute;n:',
'info_dimension' => 'Dimensiones:',
'info_document' => 'Documentu',
'info_document_indisponible' => 'Esti documentu nun ta disponible',
'info_documents' => 'Documentos',
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP permite l\'intercamb&eacute;u de mensaxes y la creaci&oacute;n de foros de discutiniu
  privaos ente los participantes nel sitiu. Pues activar o
  desactivar esta carauter&iacute;stica.',
'info_ecire_message_prive' => 'Escribir un mensaxe priv&aacute;u',
'info_email_invalide' => 'Se&ntilde;es d\'email non v&aacute;lides.',
'info_en_cours_validation' => 'Los tos art&iacute;culos en cursu de redaici&oacute;n',
'info_en_ligne' => 'Actualmente en llinia:',
'info_envoyer_message_prive' => 'Unviar un mensaxe priv&aacute;u a esti autor',
'info_erreur_requete' => 'Fallu na consulta:',
'info_erreur_squelette2' => 'Nun hai denguna cadarma <b>@fichier@</b> disponible...',
'info_erreur_systeme' => 'Fallu del sistema (errno @errsys@)',
'info_erreur_systeme2' => 'El discu duru puede tar enllenu, o la base de datos da&ntilde;ada. <br />
 <font color=\'red\'>Tenta <a href=\'@script@\'>iguar la base</a>,
 o ponte en contautu col to agospiamientu.</font>',
'info_fini' => '&iexcl;Acabose!',
'info_format_image' => 'Formatos d\'imaxe que pueden utilizase pa crear les vi&ntilde;etes: @gd_formats@.',
'info_format_non_defini' => 'formatu nun defin&iacute;u',
'info_grand_ecran' => 'Pantalla completa',
'info_image_aide' => 'AIDA',
'info_image_process_titre' => 'Metodo de fabricaci&oacute;n de les vi&ntilde;etes',
'info_impossible_lire_page' => '<b>&iexcl;Fallu!</b> Nun ye posible lleer la p&aacute;xina <tt><html>@test_proxy@</html></tt> al travi&eacute;s del proxy ',
'info_inclusion_directe' => 'Inclusi&oacute;n direuta:',
'info_inclusion_vignette' => 'Inclusi&oacute;n de la vi&ntilde;eta:',
'info_installation_systeme_publication' => 'Instalaci&oacute;n del sistema d\'espublizamientu...',
'info_installer_documents' => 'Puedes instalar autom&aacute;ticamente tolos documentos contenios nel direutoriu @upload@.',
'info_installer_ftp' => 'Como alministrador, puedes instalar ficheros (per FTP) nel direutoriu @upload@ pa poder llu&eacute;u seleicionalos direutamente equ&iacute;.',
'info_installer_images' => 'Puedes instalar imaxes nos formatos JPEG, GIF y PNG.',
'info_installer_images_dossier' => 'Instalar im&aacute;xenes nel direutoriu @upload@ pa poder seleicionales equ&iacute;.',
'info_installer_tous_documents' => 'Instalar tolos documentos',
'info_interface_complete' => 'interfaz completa',
'info_interface_simple' => 'Interfaz simplificada',
'info_joindre_document_article' => 'Pues amesta-y a esti art&iacute;culu documentos de tipu',
'info_joindre_document_rubrique' => 'Pues amestar na estaya documentos de tipu',
'info_joindre_documents_article' => 'Pues amesta-y al to art&iacute;culu documentos de tipu:',
'info_l_article' => 'l\'art&iacute;culu',
'info_la_breve' => 'la breve',
'info_la_rubrique' => 'la estaya',
'info_langue_principale' => 'Llingua principal del sitiu',
'info_largeur_vignette' => '@largeur_vignette@ &times; @hauteur_vignette@ p&iacute;xeles',
'info_les_auteurs_1' => 'por @les_auteurs@',
'info_logo_format_interdit' => 'S&oacute;lo tan autoriz&aacute;os los formatos @formats@ pa los logos.',
'info_logo_max_poids' => 'Los logos han tener obligatoriamente menos de @maxi@ (el ficheru tien @actuel@).',
'info_logo_max_taille' => 'Los logos han tener obligatoriamente menos de @maxi@ (el ficheru tien @actuel@).',
'info_mail_fournisseur' => 'el_to_nome@de.correu.ast',
'info_message_2' => 'MENSAXE',
'info_message_supprime' => 'MENSAXE DESANICI&Aacute;U',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Fecha d\'espublizamientu:',
'info_modification_parametres_securite' => 'camb&eacute;os de los par&aacute;metros de segurid&aacute;',
'info_mois_courant' => 'A lo llargo d\'esti mes:',
'info_mot_cle_ajoute' => 'La pallabra-clave darr&eacute;u amest&oacute;se a',
'info_multi_herit' => 'Ll&iacute;ngua por omisi&oacute;n',
'info_multi_langues_soulignees' => 'Les <u>ll&iacute;ng&uuml;es solli&ntilde;&aacute;es</u> beneficiense de la traducci&oacute;n de tolos testos de la interfaz. Si seleiciones estes ll&iacute;ng&uuml;es, van traducise autom&aacute;ticamente abondos elementos del sitiu p&uacute;blicu (feches, formularios). Pa les ll&iacute;ng&uuml;es non solli&ntilde;&aacute;es, estos elementos apaecer&aacute;n na llingua principal del sitiu.',
'info_multilinguisme' => 'Multilling&uuml;ismu',
'info_nom_non_utilisateurs_connectes' => 'El to nome nun apaez na llista d\'usuarios coneutaos.',
'info_nom_utilisateurs_connectes' => 'El to nome apaez na llista d\'usuarios coneut&aacute;os.',
'info_nombre_en_ligne' => 'En llinia agora:',
'info_non_resultat' => 'Deng&uacute;n result&aacute;u pa "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Nun tas usando la mensaxer&iacute;a interna d\'esti sitiu.',
'info_nouveau_message' => 'TIENES UN MENSAXE NUEVU',
'info_nouveaux_messages' => 'TIENES @total_messages@ MENSAXES NUEVOS',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Esta informaci&oacute;n ye obligatoria',
'info_panne_site_syndique' => 'Sitiu sindicau ensin serviciu',
'info_pense_bete' => 'RECORDATORIU',
'info_petit_ecran' => 'Pantalla peque&ntilde;a',
'info_petition_close' => 'Solicit&uacute; pesllada',
'info_pixels' => 'p&iacute;xels',
'info_plusieurs_mots_trouves' => 'Alcontr&aacute;ronse delles pallabres-clave pa "@cherche_mot@":',
'info_popularite_5' => 'popularid&aacute;:',
'info_portfolio' => 'Maletu',
'info_portfolio_automatique' => 'Maletu autom&aacute;ticu:',
'info_premier_resultat' => '[@debut_limit@ primeros resultaos de @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ primeros resultaos de @total@]',
'info_probleme_grave' => 'problema de',
'info_propose_1' => '[@nom_site_spip@] Propuesta: @titre@',
'info_propose_2' => 'Art&iacute;culu propuestu
------------------',
'info_propose_3' => 'L\'art&iacute;culu "@titre@" vien de proponese pa ser espubliz&aacute;u.',
'info_propose_4' => 'Quedes convid&aacute;u a consultalu y a dar la to opini&oacute;n',
'info_propose_5' => 'nel foru que tien axuntu. Ti&eacute;neslu disponible n\'estes se&ntilde;es:',
'info_publie_01' => 'L\'art&iacute;culu "@titre@" qued&oacute; valid&aacute;u por @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBLIC&Aacute;U: @titre@',
'info_publie_2' => 'Art&iacute;culu public&aacute;u
--------------',
'info_rechercher' => 'Restolar',
'info_rechercher_02' => 'Restolar:',
'info_remplacer_vignette' => 'Cambear la vi&ntilde;eta por omisi&oacute;n por un logo personaliz&aacute;u:',
'info_retablir_lien' => 'reestablecer esti enllaz',
'info_retirer_mot' => 'Retirar esta pallabra',
'info_retirer_mots' => 'Retirar toles pallabres',
'info_rubriques_nb' => '@nb@ rubriques', # NEW
'info_rubriques_un' => '1 rubrique', # NEW
'info_sans_titre_2' => 'ensin t&iacute;tulu',
'info_selectionner_fichier' => 'Puedes escoyer un ficheru del direutoriu @upload@',
'info_selectionner_fichier_2' => 'Escueye un ficheru:',
'info_signature_supprimee' => 'Robla desaniciada',
'info_signature_supprimee_erreur' => 'Error: esi c&oacute;digu de desaniciu nun concasa con denguna robla',
'info_site_attente' => 'Sitiu Web esperando validaci&oacute;n',
'info_site_reference' => 'Sitiu referenci&aacute;u en llinia',
'info_site_refuse' => 'Sitiu Web refug&aacute;u',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Referenciar un sitiu Web',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'desaniciar la vi&ntilde;eta',
'info_symbole_bleu' => 'La marca <b>azul</b> indica un <b>recordatoriu</b>: ye un mensaxe pal to usu personal.',
'info_symbole_jaune' => 'La marca <b>mariella</b> indica una <b>anuncia pa tolos redactores</b>: puede modificase por tolos alministradores, y ye visible por tolos redactores.',
'info_symbole_vert' => 'La marca <b>verde</b> indica los <b>mensaxes intercambeaos con otros usuarios</b> del sitiu.',
'info_syndication' => 'sindicaci&oacute;n:',
'info_syndication_articles' => 'art&iacute;culu(os)',
'info_telecharger' => 'Subir dende\'l to ordenador:',
'info_telecharger_nouveau_logo' => 'Subir un logo nuevu:',
'info_telecharger_ordinateur' => 'Subir dende\'l to ordenador:',
'info_tous_resultats_enregistres' => '[tolos resultaos tan grabaos]',
'info_tout_afficher' => 'Amosalo too',
'info_travaux_texte' => 'Esti sitiu nun ta iguao tov&iacute;a. Torna m&aacute;s tarde...',
'info_travaux_titre' => 'Sitiu n\'obres',
'info_trop_resultat' => 'Hai demasiaos resultaos pa "@cherche_mot@"; tienes que afinar meyor los criterios.',
'info_utilisation_messagerie_interne' => 'Tas usando la mensaxer&iacute;a interna d\'esti sitiu.',
'info_valider_lien' => 'validar esti enllaz',
'info_verifier_image' => ', has comprobar que les tos imaxes tresfirieranse correutamente.',
'info_vignette_defaut' => 'Vi&ntilde;eta por omisi&oacute;n',
'info_vignette_personnalisee' => 'Vi&ntilde;eta personalizada',
'info_visite' => 'visita:',
'info_visites' => 'visites:',
'info_vos_rendez_vous' => 'Aconceyamientos pendientes',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'Los tos recordatorios',
'item_breve_proposee' => 'Breve propuesta',

// L
'lien_afficher_icones_seuls' => 'Amosar nam&aacute;i los iconos',
'lien_afficher_texte_icones' => 'Amosar los iconos y el testu',
'lien_afficher_texte_seul' => 'Amosar s&oacute;lo el testu',
'lien_liberer' => 'lliberar',
'lien_liberer_tous' => 'lliberar estos art&iacute;culos',
'lien_nouvea_pense_bete' => 'RECORDATORIU NUEVU',
'lien_nouveau_message' => 'MENSAXE NUEVU',
'lien_nouvelle_annonce' => 'ANUNCIU NUEVU',
'lien_petitions' => 'SOLICIT&Uacute;',
'lien_popularite' => 'popularid&aacute;: @popularite@%',
'lien_racine_site' => 'RA&Iacute;Z DEL SITIU',
'lien_reessayer' => 'retentar',
'lien_repondre_message' => 'Responder a esti mensaxe',
'lien_supprimer' => 'desaniciar',
'lien_tout_afficher' => 'Amosalo too',
'lien_visite_site' => 'visitar esti sitiu',
'lien_visites' => '@visites@&nbsp;visites',
'lien_voir_auteur' => 'Ver esti autor',
'ligne' => 'Llinia',
'login' => 'Conex&oacute;n',
'login_acces_prive' => 'accesu a l\'espaciu priv&aacute;u',
'login_autre_identifiant' => 'coneutase con otru alcu&ntilde;u',
'login_cookie_accepte' => 'Ties que regular el to &ntilde;avegador pa que les acepte (polo menos pa esti sitiu).',
'login_cookie_oblige' => 'Pa identificate de mou seguru nesti sitiu, ties que aceptar les cookies.',
'login_deconnexion_ok' => 'Fecha la desconex&oacute;n.',
'login_erreur_pass' => 'Fallu de contrase&ntilde;a.',
'login_espace_prive' => 'espaciu priv&aacute;u',
'login_identifiant_inconnu' => 'L\'alcu&ntilde;u &laquo;@login@&raquo; ye desconoc&iacute;u.',
'login_login' => 'Nome d\'usuariu:',
'login_login2' => 'Login (alcu&ntilde;u de conex&oacute;n al sitiu):',
'login_login_pass_incorrect' => '(Login o contrase&ntilde;a incorreutu.)',
'login_motpasseoublie' => '&iquest;escaecisti&nbsp;la&nbsp;contrase&ntilde;a?',
'login_non_securise' => 'Atenci&oacute;n, esti formulariu nun ye seguru.
   Si nun quies que la to contrase&ntilde;a pueda
   interceutase pel cam&iacute;n, tienes qu\'activar
   Javascript nel to &ntilde;avegador y',
'login_nouvelle_tentative' => 'Nuevu intentu',
'login_par_ici' => 'Tas rexistr&aacute;u... per equ&iacute;...',
'login_pass2' => 'Contrase&ntilde;a:',
'login_preferez_refuser' => '<b>Si qui&eacute;s m&aacute;s refugar les cookies</b>, tenemos disponible otru m&eacute;todu de conex&oacute;n (enforma menos seguru):',
'login_recharger' => 'recargar esta p&aacute;xina',
'login_rester_identifie' => 'Quedar identific&aacute;u pa dellos d&iacute;es',
'login_retour_public' => 'Tornar pal sitiu p&uacute;blicu',
'login_retour_site' => 'Tornar pal sitiu p&uacute;blicu',
'login_retoursitepublic' => 'tornar&nbsp;pal&nbsp;sitiu&nbsp;p&uacute;blicu',
'login_sans_cookiie' => 'Identificaci&oacute;n ensin cookie',
'login_securise' => 'Login s&eacute;curis&eacute;', # NEW
'login_sinscrire' => 'inscribise',
'login_test_navigateur' => 'preba de &ntilde;avegador/reconex&oacute;n',
'login_verifiez_navigateur' => '(Verifica dafechu que\'l &ntilde;avegador nun s\'alcuerde de la to contrase&ntilde;a...)',

// M
'masquer_colonne' => 'Tapecer esta columna',
'masquer_trad' => 'tapecer les traducciones',
'module_fichiers_langues' => 'Archivos de llingua',

// N
'navigateur_pas_redirige' => 'Si el to &ntilde;avegador nun te redirixe, calca equ&iacute; pa continuar.',
'numero' => 'N&uacute;mberu',

// O
'occurence' => 'Ocurrencia',
'onglet_affacer_base' => 'Desaniciar la base',
'onglet_auteur' => 'L\'autor',
'onglet_contenu_site' => 'Conten&iacute;u del sitiu',
'onglet_evolution_visite_mod' => 'Evoluci&oacute;n',
'onglet_fonctions_avances' => 'Funciones avanz&aacute;es',
'onglet_informations_personnelles' => 'Informaci&oacute;n personal',
'onglet_interactivite' => 'Interactivid&aacute;',
'onglet_messagerie' => 'Mensaxer&iacute;a',
'onglet_messages_internes' => 'Mensaxes internos',
'onglet_messages_publics' => 'Mensaxes p&uacute;blicos',
'onglet_messages_vide' => 'Mensaxes ensin testu',
'onglet_origine_visites' => 'Orixe de les visites',
'onglet_repartition_debut' => 'dende l\'entamu',
'onglet_repartition_lang' => 'Repart&iacute;o por lling&uuml;es',
'onglet_repartition_rubrique' => 'Repart&iacute;o por estayes',
'onglet_save_restaur_base' => 'Sofitar/restaurar la base',
'onglet_vider_cache' => 'Vaciar la cach&eacute;',
'ortho_trop_de_fautes2' => 'Entama por iguar les faltes m&aacute;s evidentes y llu&eacute;u torna a intentalo.',

// P
'pass_choix_pass' => 'Escueye la nueva contrase&ntilde;a:',
'pass_erreur' => 'Error',
'pass_erreur_acces_refuse' => '<b>Error:</b> ya nun tienes accesu a esti sitiu.',
'pass_erreur_code_inconnu' => '<b>Error:</b> esti c&oacute;digu nun correspuende a deng&uacute;n visitante que tenga accesu a esti sitiu.',
'pass_erreur_non_enregistre' => '<b>Error:</b> les se&ntilde;es <tt>@email_oubli@</tt> nun tan rexistr&aacute;es n\'esti sitiu.',
'pass_erreur_non_valide' => '<b>Error:</b> &iexcl;estes se&ntilde;es <tt>@email_oubli@</tt> nun son v&aacute;lides!',
'pass_erreur_probleme_technique' => '<b>Error:</b> por cuenta d\'un problema t&eacute;unicu, nun pudo mandase l\'email.',
'pass_espace_prive_bla' => 'L\'espaciu priv&aacute;u d\'esti sitiu ta abiertu pa lo
  visitantes tres d\'inscribise. Desque te rexistres,
  vas poder consultar los art&iacute;culos en cursu de redaici&oacute;n,
  proponer art&iacute;culos y participar en tolos foros.',
'pass_forum_bla' => 'Pedisti intervenir nun foru acutao
  pa los visitantes rexistraos.',
'pass_indiquez_cidessous' => 'Escribe embaxo les se&ntilde;es d\'email coles que
   teas rexistr&aacute;u. Vas recibir un email
   nel que te indicamos los pasos a dar
   pa volver a tener accesu.',
'pass_mail_passcookie' => '(esti ye un mensaxe autom&aacute;ticu)
Pa volver a tener accesu al sitiu
@nom_site_spip@ (@adresse_site@)

Ties que dir a les siguientes se&ntilde;es:

    @sendcookie@

Agora vas poder escoyer una contrase&ntilde;a nueva
pa volver a coneutate al sitiu.

',
'pass_mot_oublie' => 'Contrase&ntilde;a escaecida',
'pass_nouveau_enregistre' => 'La nueva contrase&ntilde;a qued&oacute; rexistrada.',
'pass_nouveau_pass' => 'Contrase&ntilde;a nueva',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Contrase&ntilde;a escaecida',
'pass_quitter_fenetre' => 'Zarrar esta ventana',
'pass_rappel_login' => 'Recuerda: la to identid&aacute; (login) ye &laquo; @login@ &raquo;.',
'pass_recevoir_mail' => 'Vas recibir un email que te indica c&oacute;mo volver a tener accesu al sitiu.',
'pass_retour_public' => 'Volver pal sitiu p&uacute;blicu',
'pass_rien_a_faire_ici' => 'Nun hai qu&eacute; facer equ&iacute;.',
'pass_vousinscrire' => 'Apuntate a esti sitiu',
'precedent' => 'anterior',
'previsualisation' => 'G&uuml;eyada',
'previsualiser' => 'Preag&uuml;eyar',

// R
'retour' => 'Tornar',

// S
'spip_conforme_dtd' => 'SPIP considera q\'esti documentu ta conforme col so DOCTYPE:',
'squelette' => 'cadarma',
'squelette_inclus_ligne' => 'cadarma incluy&iacute;a, ll&iacute;nia',
'squelette_ligne' => 'cadarma, ll&iacute;nia',
'stats_visites_et_popularite' => '@visites@ visites; popularid&aacute;: @popularite@',
'suivant' => 'siguiente',

// T
'taille_ko' => '@taille@&nbsp;KB',
'taille_mo' => '@taille@&nbsp;MB',
'taille_octets' => '@taille@&nbsp;bytes',
'texte_actualite_site_1' => 'Cuando y&aacute; t\'afayes cola interfaz, puedes calcar en &laquo;',
'texte_actualite_site_2' => 'interfaz completa',
'texte_actualite_site_3' => '&raquo; pa amosar m&aacute;s posibilid&aacute;es.',
'texte_creation_automatique_vignette' => 'La creaci&oacute;n autom&aacute;tica de miniatures de vista previa ta activa nesti sitiu. Si instales dende esti formulariu im&aacute;xenes en formatu(os) @gd_formats@, elles van acompa&ntilde;ase d\'una miniatura con un tama&ntilde;u m&aacute;ximu de @taille_preview@&nbsp;pixels.',
'texte_documents_associes' => 'Los siguientes documentos tan asociaos al art&iacute;culu,
    pero nun tan enxertaos direutamente
    Dependiendo de la compaxinaci&oacute;n del sitiu p&uacute;blicu,
    podr&aacute;n apaecer en forma de documentos axuntos.',
'texte_erreur_mise_niveau_base' => 'Error mientres se adautaba la base de datos.
  La imaxen <b>@fichier@</b> nun se pas&oacute; (art&iacute;culu @id_article@).
  Acu&eacute;rdate d\'esta referencia, vuelve a probar la
  adautaci&oacute;n, y llueu mira si les im&aacute;xenes apaecen
  siempre nos art&iacute;culos.',
'texte_erreur_visiteur' => 'Acabes de tentar la entrada nel espaciu priv&aacute;u con un login que nun lo permite.',
'texte_inc_auth_1' => 'Identific&aacute;stete col nome
<b>@auth_login@</b>, pero &eacute;sti nun esiste na base.
Intenta',
'texte_inc_auth_2' => 'reconeutar',
'texte_inc_auth_3' => ', tres de q\'hayas, nel so casu, zarr&aacute;o y
  vuelto a abrir el to &ntilde;avegador.',
'texte_inc_config' => 'Les ig&uuml;es feches nestes p&aacute;xines influyen abondo nel
 funcionamientu del to sitiu. Encament&aacute;mos-te de nun tocales demientres que nun tes
 familiariz&aacute;u col funcionamientu del sistema SPIP. <br /><br /><b>M&aacute;s en xeneral, encamentamos
 dexar que s\'encargue d\'estes p&aacute;xines el webmaster principal del sitiu.</b>',
'texte_inc_meta_1' => 'El sistema atop&oacute; un error mientres s\'escrib&iacute;a el ficheru <code>@fichier@</code>. Como alministrador del sitiu,',
'texte_inc_meta_2' => 'hai que verificar los permisos d\'escritura',
'texte_inc_meta_3' => 'nel direutoriu <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'en cursu de redaici&oacute;n',
'texte_statut_poubelle' => 'na papelera',
'texte_statut_propose_evaluation' => 'propuestu pa so evaluaci&oacute;n',
'texte_statut_publie' => 'public&aacute;u en ll&iacute;nia',
'texte_statut_refuse' => 'refug&aacute;u',
'titre_ajouter_mot_cle' => 'AMESTAR UNA PALLABRA-CLAVE:',
'titre_breve_proposee' => 'Breve propuesta',
'titre_breve_publiee' => 'Breve publicada',
'titre_breve_refusee' => 'Breve refugada',
'titre_cadre_raccourcis' => 'ATAYOS:',
'titre_changer_couleur_interface' => 'Cambear la color de l\'interfaz',
'titre_forum' => 'Foru',
'titre_image_admin_article' => 'Puedes alministrar esti art&iacute;culu',
'titre_image_administrateur' => 'Alministrador',
'titre_image_aide' => 'Aida so esti elementu',
'titre_image_auteur_supprime' => 'Autor desanici&aacute;u',
'titre_image_redacteur' => 'Redactor ensin accesu',
'titre_image_redacteur_02' => 'Redactor',
'titre_image_visiteur' => 'Visitante',
'titre_joindre_document' => 'AMESTAR UN DOCUMENTU',
'titre_liens_entrants' => 'Enllaces entrantes',
'titre_mots_cles' => 'PALLABRES-CLAVE',
'titre_probleme_technique' => 'Atenci&oacute;n: por cuenta d\'un fallu tecnicu (servidor SQL) ta torg&aacute;u l\'accesu a esta parte del sitiu web. Fonderes disculpes, encament&aacute;mos-te que tornes n\'otru momentu.',
'titre_publier_document' => 'ESPUBLIZAR UN DOCUMENTU NESTA ESTAYA',
'titre_signatures_attente' => 'Robles n\'espera de validaci&oacute;n',
'titre_signatures_confirmees' => 'Robles confirm&aacute;es',
'titre_statistiques' => 'Estad&iacute;stiques del sitiu',
'titre_titre_document' => 'T&iacute;tulu del documentu:',
'todo' => 'por llegar',
'trad_reference' => '(art&iacute;culu orixinal)',

// Z
'zbug_balise_b_aval' => '&nbsp;: baliza B detr&aacute;s',
'zbug_balise_inexistante' => 'La baliza @balise@ ta mal declarada pa @from@',
'zbug_balise_sans_argument' => 'Falta un par&aacute;metru na baliza @balise@',
'zbug_boucle' => 'bucle',
'zbug_boucle_recursive_undef' => 'Bucle recursivu non defin&iacute;u: @nom@',
'zbug_calcul' => 'c&aacute;lculu',
'zbug_champ_hors_boucle' => 'Campu @champ@ fuera de bucle',
'zbug_champ_hors_motif' => 'El campu @champ@ ta fuera d\'un contestu @motif@',
'zbug_code' => 'c&oacute;digu',
'zbug_critere_inconnu' => 'Criteriu desconoc&iacute;u @critere@',
'zbug_distant_interdit' => 'Esternu torg&aacute;u',
'zbug_doublon_table_sans_cle_primaire' => 'Repet&iacute;os nuna tabla ensin clave primaria simple',
'zbug_doublon_table_sans_index' => 'Duplicaos nuna tabla ensin &iacute;ndiz',
'zbug_erreur_boucle_double' => 'Doble definici&oacute;n del bucle @id@',
'zbug_erreur_boucle_fermant' => 'El bucle @id@ ta ensin zarrar',
'zbug_erreur_boucle_syntaxe' => 'Sintaxis del bucle @id@ incorreuta',
'zbug_erreur_compilation' => 'Error de compilaci&oacute;n',
'zbug_erreur_execution_page' => 'Error d\'execuci&oacute;n',
'zbug_erreur_filtre' => 'El filtru @filtre@ nun ta defin&iacute;u',
'zbug_erreur_meme_parent' => 'El criteriu {meme_parent} nun s\'aplica m&aacute;s que a los bucles (FORUMS) o (RUBRIQUES)',
'zbug_erreur_squelette' => 'Error(es) na cadarma',
'zbug_hors_compilation' => 'Fuera de Compilaci&oacute;n',
'zbug_info_erreur_squelette' => 'Error nel sitiu',
'zbug_inversion_ordre_inexistant' => 'Inversi&oacute;n d\'un orde inesistente',
'zbug_pagination_sans_critere' => 'Baliza #PAGINATION ensin criteriu {pagination} o emplegada nun bucle recursivu',
'zbug_parametres_inclus_incorrects' => 'Par&aacute;metru d\'inclusi&oacute;n incorreutu: @param@',
'zbug_profile' => 'Tiempu pal c&aacute;lculu: @time@',
'zbug_resultat' => 'result&aacute;u',
'zbug_serveur_indefini' => 'Sirvidor SQL indefin&iacute;u',
'zbug_statistiques' => 'Estad&iacute;stiques de les consultes SQL clasificaes por duraci&oacute;n',
'zbug_table_inconnue' => 'Tabla SQL &laquo;@table@&raquo; desconoc&iacute;a',
'zxml_connus_attributs' => 'atributos conoc&iacute;os',
'zxml_de' => 'de',
'zxml_inconnu_attribut' => 'atributu desconoc&iacute;u',
'zxml_inconnu_balise' => 'baliza desconoc&iacute;a',
'zxml_inconnu_entite' => 'entid&aacute; desconoc&iacute;a',
'zxml_inconnu_id' => 'ID desconoc&iacute;a',
'zxml_mais_de' => 'm&aacute;s de',
'zxml_non_conforme' => 'nun ye conforme al motivu',
'zxml_non_fils' => 'nun ye un fiu de',
'zxml_nonvide_balise' => 'etiqueta non vac&iacute;a',
'zxml_obligatoire_attribut' => 'atributu obligatoriu pero que falta en',
'zxml_succession_fils_incorrecte' => 'sucesi&oacute;n de los fios incorreuta',
'zxml_survoler' => 'pasar el mur pa ver los correutos',
'zxml_valeur_attribut' => 'valor de l\'atributu',
'zxml_vide_balise' => 'etiqueta vac&iacute;a',
'zxml_vu' => 'visto enantes'
);

?>
